import math

def apply_sqrt(inp):
    out = math.sqrt(inp) +1000
    return -out